@@ -128,11 +128,11 @@ gnome_vfs_drive_init (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_ref:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
+ * Increases the refcount of the @drive by 1.
  *
- *
- * Returns:
+ * Returns: the @drive.
  *
  * Since: 2.6
  */
@@ -151,9 +151,9 @@ gnome_vfs_drive_ref (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_unref:
- * @drive:
- *
+ * @drive: a #GnomeVFSDrive.
  *
+ * Decreases the refcount of the @drive by 1.
  *
  * Since: 2.6
  */
@@ -185,8 +185,7 @@ gnome_vfs_drive_finalize (GObject *object)
 		GnomeVFSVolume *vol;
 		vol = GNOME_VFS_VOLUME (current_vol->data);
 
-		_gnome_vfs_volume_unset_drive (vol,
-					       drive);
+		gnome_vfs_volume_unset_drive_private (vol, drive);
 		gnome_vfs_volume_unref (vol);
 	}
 
@@ -196,6 +195,8 @@ gnome_vfs_drive_finalize (GObject *object)
 	g_free (priv->display_name);
 	g_free (priv->icon);
 	g_free (priv->hal_udi);
+	g_free (priv->hal_drive_udi);
+	g_free (priv->hal_backing_crypto_volume_udi);
 	g_free (priv);
 	drive->priv = NULL;
 	
@@ -205,11 +206,9 @@ gnome_vfs_drive_finalize (GObject *object)
 
 /** 
  * gnome_vfs_drive_get_id:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: drive id, a #gulong value.
  *
  * Since: 2.6
  */
@@ -221,11 +220,9 @@ gnome_vfs_drive_get_id (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_device_type:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: device type, a #GnomeVFSDeviceType value.
  *
  * Since: 2.6
  */
@@ -237,13 +234,14 @@ gnome_vfs_drive_get_device_type (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_mounted_volume:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
+ * Returns the first mounted volume for the @drive.
  *
- *
- * Returns:
+ * Returns: a #GnomeVFSVolume.
  *
  * Since: 2.6
+ * Deprecated: Use gnome_vfs_drive_get_mounted_volumes() instead.
  */
 GnomeVFSVolume *
 gnome_vfs_drive_get_mounted_volume (GnomeVFSDrive *drive)
@@ -267,11 +265,11 @@ gnome_vfs_drive_get_mounted_volume (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_volume_list_free:
- * @volumes:
+ * @volumes: list of #GnomeVFSVolumes to be freed.
  *
+ * Frees the list @volumes.
  *
- *
- * Since: 2.6
+ * Since: 2.8
  */
 void
 gnome_vfs_drive_volume_list_free (GList *volumes)
@@ -287,13 +285,11 @@ gnome_vfs_drive_volume_list_free (GList *volumes)
 
 /** 
  * gnome_vfs_drive_get_mounted_volumes:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
+ * Returns: list of mounted volumes for the @drive.
  *
- *
- * Returns:
- *
- * Since: 2.6
+ * Since: 2.8
  */
 GList *
 gnome_vfs_drive_get_mounted_volumes (GnomeVFSDrive *drive)
@@ -313,11 +309,9 @@ gnome_vfs_drive_get_mounted_volumes (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_is_mounted:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: %TRUE if the @drive is mounted, %FALSE otherwise.
  *
  * Since: 2.6
  */
@@ -334,8 +328,8 @@ gnome_vfs_drive_is_mounted (GnomeVFSDrive *drive)
 }
 
 void
-_gnome_vfs_drive_remove_volume (GnomeVFSDrive      *drive,
-			       GnomeVFSVolume     *volume)
+gnome_vfs_drive_remove_volume_private (GnomeVFSDrive      *drive,
+				       GnomeVFSVolume     *volume)
 {
 	G_LOCK (drives);
 	g_assert ((g_list_find (drive->priv->volumes,
@@ -348,8 +342,8 @@ _gnome_vfs_drive_remove_volume (GnomeVFSDrive      *drive,
 }
 
 void
-_gnome_vfs_drive_add_mounted_volume  (GnomeVFSDrive      *drive,
-				      GnomeVFSVolume     *volume)
+gnome_vfs_drive_add_mounted_volume_private (GnomeVFSDrive      *drive,
+					    GnomeVFSVolume     *volume)
 {
 	G_LOCK (drives);
 
@@ -364,11 +358,9 @@ _gnome_vfs_drive_add_mounted_volume  (GnomeVFSDrive      *drive,
 
 /** 
  * gnome_vfs_drive_get_device_path:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns: a newly allocated string
+ * Returns: a newly allocated string for the device path of the #drive.
  *
  * Since: 2.6
  */
@@ -380,11 +372,9 @@ gnome_vfs_drive_get_device_path (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_activation_uri:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns: a newly allocated string
+ * Returns: a newly allocated string for the activation uri of the #drive.
  *
  * Since: 2.6
  */
@@ -396,11 +386,9 @@ gnome_vfs_drive_get_activation_uri (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_hal_udi:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns: a newly allocated string
+ * Returns: a newly allocated string for the unique device id of the @drive.
  *
  * Since: 2.6
  */
@@ -412,11 +400,9 @@ gnome_vfs_drive_get_hal_udi (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_display_name:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns: a newly allocated string
+ * Returns: a newly allocated string for the display name of the @drive.
  *
  * Since: 2.6
  */
@@ -428,11 +414,9 @@ gnome_vfs_drive_get_display_name (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_get_icon:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns: a newly allocated string
+ * Returns: a newly allocated string for the icon filename of the @drive.
  *
  * Since: 2.6
  */
@@ -444,11 +428,9 @@ gnome_vfs_drive_get_icon (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_is_user_visible:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: %TRUE if the @drive is visible to the user, %FALSE otherwise.
  *
  * Since: 2.6
  */
@@ -460,11 +442,9 @@ gnome_vfs_drive_is_user_visible (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_is_connected:
- * @drive:
+ * @drive: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: %TRUE if the @drive is connected, %FALSE otherwise.
  *
  * Since: 2.6
  */
@@ -476,12 +456,10 @@ gnome_vfs_drive_is_connected (GnomeVFSDrive *drive)
 
 /** 
  * gnome_vfs_drive_compare:
- * @a:
- * @b:
+ * @a: a #GnomeVFSDrive.
+ * @b: a #GnomeVFSDrive.
  *
- *
- *
- * Returns:
+ * Returns: 0 if the drives are same.
  *
  * Since: 2.6
  */
@@ -531,10 +509,10 @@ decode_corba_string_or_null (CORBA_char *str, gboolean empty_is_null)
 
 /** 
  * gnome_vfs_drive_to_corba:
- * @drive:
- * @corba_drive:
- *
+ * @drive: a #GnomeVFSDrive.
+ * @corba_drive: a GNOME_VFS_Drive object.
  *
+ * Fills @corba_drive with the values from @drive.
  *
  * Since: 2.6
  */
@@ -604,8 +582,8 @@ _gnome_vfs_drive_from_corba (const GNOME_VFS_Drive *corba_drive,
 			GnomeVFSVolume *volume = gnome_vfs_volume_monitor_get_volume_by_id (volume_monitor,
 										 corba_drive->volumes._buffer[i]);
 			if (volume != NULL) {
-				_gnome_vfs_drive_add_mounted_volume (drive, volume);
-				_gnome_vfs_volume_set_drive (volume, drive);
+				gnome_vfs_drive_add_mounted_volume_private (drive, volume);
+				gnome_vfs_volume_set_drive_private (volume, drive);
 			}
 		}
 	}
