@@ -45,6 +45,7 @@
 #include <libgnomevfs/gnome-vfs-module-callback-module-api.h>
 #include <libgnomevfs/gnome-vfs-module.h>
 #include <libgnomevfs/gnome-vfs-module-shared.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-parse-ls.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <stdio.h> /* for sscanf */
@@ -608,6 +609,7 @@ do_path_command (FtpConnection *conn,
 	 * than the full path. Useful for some (buggy?) systems. */
 	unescaped = gnome_vfs_unescape_string (uri->text, G_DIR_SEPARATOR_S);
 	if (unescaped == NULL || unescaped[0] == '\0') {
+		g_free (unescaped);
 		unescaped = g_strdup ("/");
 	}
 
@@ -774,6 +776,7 @@ do_path_transfer_command (FtpConnection *conn, gchar *command, GnomeVFSURI *uri,
 
 	unescaped = gnome_vfs_unescape_string (uri->text, G_DIR_SEPARATOR_S);
 	if (unescaped == NULL || unescaped[0] == '\0') {
+		g_free (unescaped);
 		unescaped = g_strdup ("/");
 	}
 
@@ -1618,7 +1621,7 @@ invalidate_dirlist_cache (GnomeVFSURI *uri)
 	G_LOCK (connection_pools);
 	pool = ftp_connection_pool_lookup (uri);
 	g_hash_table_remove (pool->cached_dirlists,
-			     uri->text);
+			     uri->text != NULL ? uri->text : "/");
 	G_UNLOCK (connection_pools);
 }
 
@@ -2432,7 +2435,7 @@ do_open_directory (GnomeVFSMethod *method,
 	G_LOCK (connection_pools);
 	pool = ftp_connection_pool_lookup (uri);
 	cached_dirlist = g_hash_table_lookup (pool->cached_dirlists,
-					      uri->text);
+					      uri->text != NULL ? uri->text : "/");
 	if (cached_dirlist != NULL) {
 		gettimeofday (&tv, NULL);
 
@@ -2513,7 +2516,7 @@ do_open_directory (GnomeVFSMethod *method,
 	cached_dirlist->read_time = tv.tv_sec;
 	
 	g_hash_table_replace (pool->cached_dirlists,
-			      g_strdup (uri->text),
+			      g_strdup (uri->text != NULL ? uri->text : "/"),
 			      cached_dirlist);
 	
 	G_UNLOCK (connection_pools);
@@ -2635,7 +2638,7 @@ do_read_directory (GnomeVFSMethod *method,
 
 				GNOME_VFS_FILE_INFO_SET_SYMLINK (file_info, TRUE);
 				file_info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME;
-				file_info->symlink_name = gnome_vfs_unescape_string (uri->text, "/");
+				file_info->symlink_name = gnome_vfs_unescape_string (uri->text != NULL ? uri->text : "/", "/");
 				
 				g_free (file_info->name);
 				file_info->name = real_name;
@@ -2700,6 +2703,9 @@ do_make_directory (GnomeVFSMethod *method,
 		do_path_command_completely (chmod_command, uri, context,
 			GNOME_VFS_ERROR_ACCESS_DENIED);
 		g_free(chmod_command);
+	} else if (result != GNOME_VFS_ERROR_CANCELLED &&
+		   gnome_vfs_uri_exists (uri)) {
+		result = GNOME_VFS_ERROR_FILE_EXISTS;
 	}
 
 	return result;
