@@ -66,6 +66,9 @@ typedef struct ip_watched_dir_s {
 	GList *subs;
 } ip_watched_dir_t;
 
+static gboolean     ip_debug_enabled = FALSE;
+#define IP_W if (ip_debug_enabled) g_warning
+
 /* path -> ip_watched_dir */
 static GHashTable * path_dir_hash = NULL;
 /* ih_sub_t * -> ip_watched_dir *
@@ -141,23 +144,32 @@ gboolean ip_start_watching (ih_sub_t *sub)
 	int err;
 	ip_watched_dir_t *dir;
 
-	dir = g_hash_table_lookup (path_dir_hash, sub->dir);
+	g_assert (sub);
+	g_assert (!sub->cancelled);
+	g_assert (sub->dirname);
+
+	IP_W("Starting to watch %s\n", sub->dirname);
+	dir = g_hash_table_lookup (path_dir_hash, sub->dirname);
 	if (dir)
 	{
+		IP_W("Already watching\n");
 		goto out;
 	}
 	
-	wd = ik_watch (sub->dir, IP_INOTIFY_MASK|IN_ONLYDIR|sub->extra_flags, &err);
+	IP_W("Trying to add inotify watch ");
+	wd = ik_watch (sub->dirname, IP_INOTIFY_MASK|IN_ONLYDIR|sub->extra_flags, &err);
 	if (wd < 0) 
 	{
+		IP_W("Failed\n");
 		return FALSE;
 	} else {
 		/* Create new watched directory and associate it with the 
 		 * wd hash and path hash
 		 */
-		dir = ip_watched_dir_new (sub->dir, wd);
+		IP_W("Success\n");
+		dir = ip_watched_dir_new (sub->dirname, wd);
 		ip_map_wd_dir (wd, dir);
-		ip_map_path_dir (sub->dir, dir);
+		ip_map_path_dir (sub->dirname, dir);
 	}
 
 out:
@@ -177,8 +189,9 @@ static void
 ip_unmap_wd_dir (gint32 wd, ip_watched_dir_t *dir)
 {
 	GList *dir_list = g_hash_table_lookup (wd_dir_hash, GINT_TO_POINTER(wd));
+	if (!dir_list)
+		return;
 	g_assert (wd >= 0 && dir);
-	g_assert (g_list_length (dir_list) > 0);
 	dir_list = g_list_remove (dir_list, dir);
 	if (g_list_length (dir_list) == 0) {
 		g_hash_table_remove (wd_dir_hash, GINT_TO_POINTER(dir->wd));
@@ -191,8 +204,9 @@ static void
 ip_unmap_wd (gint32 wd)
 {
 	GList *dir_list = g_hash_table_lookup (wd_dir_hash, GINT_TO_POINTER(wd));
+	if (!dir_list)
+		return;
 	g_assert (wd >= 0);
-	g_assert (g_list_length (dir_list) > 0);
 	g_hash_table_remove (wd_dir_hash, GINT_TO_POINTER(wd));
 	g_list_free (dir_list);
 }
@@ -329,8 +343,8 @@ static void ip_event_dispatch (GList *dir_list, GList *pair_dir_list, ik_event_t
 			/* If the event and the subscription have a filename
 			 * they need to match before the event could be delivered.
 			 */
-			if (event->name && sub->filename) {
-				if (strcmp (event->name, sub->filename))
+			if (event->pair->name && sub->filename) {
+				if (strcmp (event->pair->name, sub->filename))
 					continue;
 			/* If the event doesn't have a filename, but the subscription does
 			 * we shouldn't deliever the event */
